@@ -5,10 +5,10 @@ use strict;
 use warnings;
 use parent 'Alien::Base';
 
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 sub cxxflags {
-    return $_[0]->config('system_provides')->{'C++flags'} // '';
+    return $_[0]->config('system_provides')->{'C++flags'} || '';
 }
 
 1;
@@ -25,7 +25,7 @@ Alien::ProtoBuf - find Google ProtoBuf library
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
